# Lithium plating parameters

Some example parameters for lithium plating from the paper:

> O’Kane, S. E. J., Ai, W., Madabattula, G., Alonso-Alvarez, D., Timms, R, Sulzer, V., Edge, J. S., Wu, B., Offer, G. J., & Marinescu, M. (2022) Lithium-ion battery degradation: how to model it. Physical Chemistry: Chemical Physics, accepted.

Note: this parameter set does not claim to be representative of the true parameter values. These are merely the parameter values that were used in the referenced papers.
